#include "tableprint.hpp"
#include <iomanip>
#include <algorithm>

tableprint::tableprint() {}

tableprint::~tableprint() {}

void tableprint::add_row(const std::vector<std::string>& row) {
    rows.push_back(row);
}

void tableprint::print() {
    if (rows.empty()) return;

    // Calculate column widths
    std::vector<size_t> col_widths(rows[0].size(), 0);
    for (const auto& row : rows) {
        for (size_t i = 0; i < row.size(); ++i) {
            col_widths[i] = std::max(col_widths[i], row[i].length());
        }
    }

    // Print header
    std::cout << "\033[1;36m"; // Cyan color for header
    for (size_t i = 0; i < rows[0].size(); ++i) {
        std::cout << std::setw(col_widths[i] + 2) << std::left << rows[0][i];
    }
    std::cout << "\033[0m" << std::endl; // Reset color

    // Print separator
    for (size_t i = 0; i < rows[0].size(); ++i) {
        std::cout << std::string(col_widths[i] + 2, '-');
    }
    std::cout << std::endl;

    // Print rows
    for (size_t row_idx = 1; row_idx < rows.size(); ++row_idx) {
        const auto& row = rows[row_idx];
        for (size_t i = 0; i < row.size(); ++i) {
            std::string cell = row[i];
            // Replace :tick: and :cross: with colored symbols
            if (cell == ":tick:") {
                std::cout << "\033[1;32m" << std::setw(col_widths[i] + 2) << std::left << "✓" << "\033[0m";
            } else if (cell == ":cross:") {
                std::cout << "\033[1;31m" << std::setw(col_widths[i] + 2) << std::left << "✗" << "\033[0m";
            } else {
                std::cout << std::setw(col_widths[i] + 2) << std::left << cell;
            }
        }
        std::cout << std::endl;
    }
} 